@@ -111,13 +111,13 @@ class StepMix(BaseEstimator):
             - 'BCH' : Apply the empirical BCH correction from *Vermunt, 2004*.
             - 'ML' : Apply the ML correction from *Vermunt, 2010; Bakk et al., 2013*.
 
-    abs_tol : float, default=1e-6
+    abs_tol : float, default=1e-10
         The convergence threshold. EM iterations will stop when the
         lower bound average gain is below this threshold.
-    rel_tol : float, default=1e-10
+    rel_tol : float, default=0.00
         The convergence threshold. EM iterations will stop when the
         relative lower bound average gain is below this threshold.
-    max_iter : int, default=100
+    max_iter : int, default=1000
         The number of EM iterations to perform.
     n_init : int, default=1
         The number of initializations to perform. The best results are kept.
@@ -214,9 +214,9 @@ class StepMix(BaseEstimator):
         structural="gaussian_unit",
         assignment="modal",
         correction=None,
-        abs_tol=1e-6,
-        rel_tol=1e-10,
-        max_iter=100,
+        abs_tol=1e-10,
+        rel_tol=0.00,
+        max_iter=1000,
         n_init=1,
         init_params="random",
         random_state=None,
@@ -242,7 +242,6 @@ class StepMix(BaseEstimator):
         self.correction = correction
 
         # Additional attributes to specify the measurement and structural models
-        # Deep copy the parameters since they are potentially dictionaries
         self.measurement = measurement
         self.measurement_params = measurement_params
         self.structural = structural
@@ -293,16 +292,23 @@ class StepMix(BaseEstimator):
 
         # Check if models support missing values
         # This is passed to sklearn.utils.check_array
-        self.force_all_finite_mm_ = (
+        self._force_all_finite_mm = (
             "allow-nan" if utils.check_descriptor_nan(self.measurement) else True
         )
-        self.force_all_finite_sm_ = (
+        self._force_all_finite_sm = (
             "allow-nan" if utils.check_descriptor_nan(self.structural) else True
         )
 
         # Buffer to save the likelihoods of different inits for debugging
         self.lower_bound_buffer_ = list()
 
+        # Covariate models have special constraints. Check them.
+        is_covariate = utils.check_covariate(self.measurement, self.structural)
+
+        # Covariate models use a different conditional likelihood (See Bakk and Kuha, 2018), which should
+        # not include the marginal likelihood over the latent classes in the E-step
+        self._class_weight_likelihood = not is_covariate
+
     def _initialize_parameters(self, X, random_state):
         """Initialize the weights and measurement model parameters.
 
@@ -399,7 +405,7 @@ class StepMix(BaseEstimator):
 
     @property
     def n_parameters(self):
-        """Get number of parameters."""
+        """Get number of free parameters."""
         check_is_fitted(self)
         n = self.n_components - 1 + self._mm.n_parameters
         if hasattr(self, "_sm"):
@@ -443,7 +449,7 @@ class StepMix(BaseEstimator):
                 X,
                 dtype=[np.float64, np.float32],
                 reset=True,
-                force_all_finite=self.force_all_finite_mm_,
+                force_all_finite=self._force_all_finite_mm,
             )
         if Y is not None:
             # Handle 1D Y array
@@ -452,7 +458,7 @@ class StepMix(BaseEstimator):
                 dtype=[np.float64, np.float32],
                 reset=True,
                 ensure_2d=False,
-                force_all_finite=self.force_all_finite_sm_,
+                force_all_finite=self._force_all_finite_sm,
             )
 
             # Force a matrix format
@@ -536,6 +542,26 @@ class StepMix(BaseEstimator):
             self._sm.set_parameters(params["structural"])
             self.structural_in_ = params["structural_in"]
 
+    def permute_classes(self, perm):
+        """Permute the latent class and associated parameters of this estimator.
+
+        Effectively remaps latent classes.
+
+        Parameters
+        ----------
+        perm : ndarray of shape  (n_classes,)
+            Integer array representing the target permutation. Should be a permutation of np.arange(n_classes).
+        """
+        check_is_fitted(self)
+        self.weights_ = self.weights_[perm]
+
+        # Permute classes of measurement model
+        self._mm.permute_classes(perm)
+
+        # Permute classes of structural model (if any)
+        if hasattr(self, "_sm"):
+            self._sm.permute_classes(perm)
+
     #######################################################################################################################
     # ESTIMATION AND EM METHODS
     def fit(self, X, Y=None, sample_weight=None, y=None):
@@ -837,7 +863,8 @@ class StepMix(BaseEstimator):
             log_resp = self._mm.log_likelihood(X)
 
         # Add class prior probabilities
-        log_resp += np.log(self.weights_).reshape((1, -1))
+        if self._class_weight_likelihood:
+            log_resp += np.log(self.weights_).reshape((1, -1))
 
         # Add structural model likelihood (if structural data is provided)
         if Y is not None:
