@@ -1,6 +1,5 @@
 import numpy as np
 import copy
-from collections import OrderedDict
 
 import pandas as pd
 import pytest
@@ -64,37 +63,72 @@ def test_covariate(data_covariate, kwargs, method, intercept):
     ll_1 = model_1.score(X, Z)  # Average log-likelihood
 
 
-def test_nested(data, kwargs):
+def test_illegal_covariate(data_covariate, kwargs_nested):
+    X, Z = data_covariate
+
+    # Make sure we can't have two covariate models.
+    with pytest.raises(ValueError) as e_info:
+        model_1 = StepMix(
+            n_steps=1,
+            measurement="covariate",
+            structural="covariate",
+        )
+        model_1.fit(X, Z)
+
+    kwargs_covariate = copy.deepcopy(kwargs_nested)
+    kwargs_covariate["measurement"]["model_1"]["model"] = "covariate"
+    with pytest.raises(ValueError) as e_info:
+        model_1 = StepMix(
+            n_steps=1,
+            measurement=kwargs_covariate["measurement"],
+            structural="covariate",
+        )
+        model_1.fit(X, Z)
+    with pytest.raises(ValueError) as e_info:
+        model_1 = StepMix(
+            n_steps=1,
+            measurement="covariate",
+            structural=kwargs_covariate["measurement"],
+        )
+        model_1.fit(X, Z)
+
+    kwargs_covariate["measurement"]["model_2"]["model"] = "covariate"
+    with pytest.raises(ValueError) as e_info:
+        model_1 = StepMix(
+            n_steps=1,
+            measurement=kwargs_covariate["measurement"],
+        )
+        model_1.fit(X)
+
+
+def test_nested(data_nested, kwargs_nested):
     """Test verbose output and sampling of nested model."""
-    X, Y = data
-
-    # For this test, ignore the measurement and structural keys in kwargs
-    kwargs.pop("measurement")
-    kwargs.pop("structural")
-
-    # Binary + Gaussian measurement
-    descriptor = {
-        "model_1": {"model": "bernoulli", "n_columns": 6},
-        "model_2": {"model": "gaussian_unit", "n_columns": 1},
-    }
-
-    # Merge data in single matrix
-    Z = np.hstack((X, Y))
 
     # We use the same measurement and structural models, both nested
-    model_3 = StepMix(
-        measurement=copy.deepcopy(descriptor),
-        structural=copy.deepcopy(descriptor),
-        **kwargs,
-    )
-    model_3.fit(Z, Z)
-    ll_3 = model_3.score(Z, Z)
-    pred_3 = model_3.predict(Z, Z)
+    model_3 = StepMix(**kwargs_nested)
+
+    # Test fit and inference
+    model_3.fit(data_nested, data_nested)
+    ll_3 = model_3.score(data_nested, data_nested)
+    pred_3 = model_3.predict(data_nested, data_nested)
 
     # Test sampling
     model_3.sample(100)
 
 
+def test_nested_twice(data_nested, kwargs_nested):
+    """Test verbose output and sampling of nested model.
+
+    Once ran into a bug where nested parameters would disappear after calling fit."""
+
+    # We use the same measurement and structural models, both nested
+    model_3 = StepMix(**kwargs_nested)
+
+    # Test fit and inference
+    model_3.fit(data_nested, data_nested)
+    model_3.fit(data_nested, data_nested)
+
+
 def test_get_descriptor(kwargs):
     """Test get_mixed_descriptor."""
     target = {
